# coding=utf-8
import time
import unittest

from alas_ce0.management.shelf import ShelfCellTemplateClient

from alas_ce0.management.shelf import ShelfRowTemplateClient, ShelfTemplateClient
from alas_ce0.management.vehicle import ShelfCargoVehicleTemplateClient, CargoVehicleTemplateClient

from config import API_ACCESS_CONFIG


class TestShelfCargoVehicleApi(unittest.TestCase):
    def test_crud(self):
        # Tests Setup

        shelf_cell_template_client = ShelfCellTemplateClient(**API_ACCESS_CONFIG)
        shelf_cell_template = {
            'volume': {
                'width': 50.25,
                'height': 60.13,
                'depth': 25.34
            }
        }

        result = shelf_cell_template_client.create(shelf_cell_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)
        shelf_cell_code = result.content['code']

        shelf_row_template_client = ShelfRowTemplateClient(**API_ACCESS_CONFIG)
        shelf_row_template = {
            'volume': {
                'width': 50.25,
                'height': 60.13,
                'depth': 25.34
            },
            'cells': [shelf_cell_code]
        }

        result = shelf_row_template_client.create(shelf_row_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)
        shelf_row_code = result.content['code']

        shelf_template_client = ShelfTemplateClient(**API_ACCESS_CONFIG)
        shelf_template = {
            'code': 'S1',
            'rows': [shelf_row_code]
        }

        result = shelf_template_client.create(shelf_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)
        shelf_code = result.content['code']

        cargo_vehicle_template_client = CargoVehicleTemplateClient(**API_ACCESS_CONFIG)
        cargo_vehicle_template = {
            "brand": "BRAND",
            "model": "MODEL",
            "cargo_weight": 4350,
            "cargo_volume": 13.0,
            "delivery_cargo_volume": {
                "width": 50.25,
                "height": 60.13,
                "depth": 25.34
            }
        }

        result = cargo_vehicle_template_client.create(cargo_vehicle_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)
        cargo_vehicle_code = result.content['code']

        # ShelfCargoVehicle Tests

        shelf_cargo_vehicle_template_client = ShelfCargoVehicleTemplateClient(**API_ACCESS_CONFIG)
        shelf_cargo_vehicle_template = {
            'cargo_vehicle_template_code': cargo_vehicle_code,
            'shelf_templates': [shelf_code]
        }

        result = shelf_cargo_vehicle_template_client.create(shelf_cargo_vehicle_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = shelf_cargo_vehicle_template_client.get_by_id(result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)

        result = shelf_cargo_vehicle_template_client.search({'code': result.content['code']})
        self.assertTrue(result.response.status == 200 and result.content)

        shelf_cargo_vehicle_template_code = result.content['items'][0]['code']
        result = shelf_cargo_vehicle_template_client.get_by_id('sample-shelf-cargo')
        self.assertTrue(result.response.status == 404)

        result = shelf_cargo_vehicle_template_client.delete(shelf_cargo_vehicle_template_code)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = shelf_cargo_vehicle_template_client.create(shelf_cargo_vehicle_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        shelf_cargo_vehicle_template['cargo_vehicle_template_code'] = cargo_vehicle_code
        result = shelf_cargo_vehicle_template_client.update(
            shelf_cargo_vehicle_template, result.content['code']
        )
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = shelf_cargo_vehicle_template_client.delete(result.content['code'])
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        # Tests Cleanup

        result = cargo_vehicle_template_client.delete(cargo_vehicle_code)
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        result = shelf_template_client.delete(shelf_code)
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        result = shelf_row_template_client.delete(shelf_row_code)
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        result = shelf_cell_template_client.delete(shelf_cell_code)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)


if __name__ == '__main__':
    unittest.main()



# coding=utf-8
import time
import unittest

from alas_ce0.management.contact import ContactClient

from alas_ce0.management.employee import EmployeeClient

from alas_ce0.management.service_level import ServiceLevelClient

from alas_ce0.management.delivery_entity import RegionalPartnerClient

from alas_ce0.management.geographic_coverage import GeographicCoverageClient

from alas_ce0.management.distribution_zone import DistributionZoneClient

from alas_ce0.management.cross_docking import CrossDockingLocationClient

from alas_ce0.management.packaging import PackagingLocationClient

from alas_ce0.management.product_template import ProductTemplateClient

from alas_ce0.management.package_template import PackageTemplateClient

from alas_ce0.delivery.b2c import B2CClient

from alas_ce0.management.delivery_entity import B2BClient

from alas_ce0.delivery.delivery_order import DeliveryOrderRequestClient

from config import API_ACCESS_CONFIG


class TestDeliveryOrderRequestApi(unittest.TestCase):
    def test_crud(self):
        # Tests Setup

        contact_client = ContactClient(**API_ACCESS_CONFIG)
        contact = {
            'code': '44444444-4',
            'first_name': 'Contact FirstName',
            'last_name': 'Contact LastName',
            'land_line': '221345678',
            'mobile_phone': '921345678',
            'email': 'contact@gmail.com',
            'web': 'http://www.contact.com'
        }

        result = contact_client.create(contact)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        b2c_client = B2CClient(**API_ACCESS_CONFIG)
        b2c = {
            "code": "10101010-1",
            "first_name": "Joh",
            "last_name": "Doe",
            "mobile_phone": "912345678",
            "email": "john.doe@gmail.com"
        }

        result = b2c_client.create(b2c)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        employee_client = EmployeeClient(**API_ACCESS_CONFIG)
        employee = {
            'first_name': 'First Nam',
            'last_name': 'Last Name',
            'code': '22222222-2',
            'birth_date': '1991-01-01',
            'gender': 1,
            'internal_code': '1',
            'status': 1
        }

        result = employee_client.create(employee)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        packaging_location_client = PackagingLocationClient(**API_ACCESS_CONFIG)
        packaging_location = {
            "code": "Directv-Fijo-Test",
            "type": 1,
            "location":{
                "country_code": "CL",
                "zone_type": 1,
                "geo_coding": "Avenida Vitacura 4380, Vitacura, Chile",
                "geo_location": {
                    "lat": -33.398823,
                    "lon": -70.588274
                },
                "what3words": "liner.cooking.montage",
                "reference": "En la esquina de Vitacura con Américo Vespucio",
                "structure_id": 13132,
                "sector": "",
                "street": "Vitacura",
                "number": "4380",
            },
            "contact": "44444444-4",
        }

        result = packaging_location_client.create(packaging_location)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        b2b_client = B2BClient(**API_ACCESS_CONFIG)
        b2b = {
            'code': '33333333-3',
            'name': 'Directv',
            'location': {
                'country_code': 'CL',
                'zone_type': 1,
                'geo_coding': 'Avenida Vitacura 4380, Vitacura, Chile',
                'geo_location': {
                    'lat': -33.398823,
                    'lon': -70.588274
                },
                'what3words': 'liner.cooking.montage',
                'reference': 'En la esquina de Vitacura con Américo Vespucio',
                'structure_id': 13132,
                'street': 'Vitacura',
                'number': '4380',
                'sector': '',
            },
            'packaging_locations': [result.content['code']],
            'business_activity': 'Televisión Satelital',
            'internal_code': '1'
        }

        result = b2b_client.create(b2b)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        package_template_client = PackageTemplateClient(**API_ACCESS_CONFIG)
        package_template = {
            "code": "Box1-Test",
            "weight": 21.25,
            "width": 11.5,
            "height": 11.3,
            "depth": 21.4,
            "box_type": 1
        }

        result = package_template_client.create(package_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        product_template_client = ProductTemplateClient(**API_ACCESS_CONFIG)
        product_template = {
            "code": "KitPrepagoDTV-Test",
            "name": "Kit Prepago",
            "description": "Kit Prepago",
            "provider_code": "33333333-3",
            "provider_name": "Directv",
            "weight": 20.25,
            "width": 10.5,
            "height": 15.3,
            "depth": 20.4,
            "box_type": 1,
            'packaging_location_code': 'Directv-Fijo-Test'
        }

        result = product_template_client.create(product_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        cross_docking_location_client = CrossDockingLocationClient(**API_ACCESS_CONFIG)
        chilean_cross_docking_location = {
            "code": "Bodega01-SCL-Test",
            "location": {
                "country_code": "CL",
                "zone_type": 1,
                "geo_coding": "Avenida Vitacura 4380, Vitacura, Chile",
                "geo_location": {
                    "lat": -33.398823,
                    "lon": -70.588274
                },
                "what3words": "liner.cooking.montage",
                "reference": "En la esquina de Vitacura con Américo Vespucio",
                "structure_id": 13132,
                "sector": "",
                "street": "Vitacura",
                "number": "4380",
            }
        }

        result = cross_docking_location_client.create(chilean_cross_docking_location)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        distribution_zone_client = DistributionZoneClient(**API_ACCESS_CONFIG)
        distribution_zone = {
            "code": "RM-01-Test",
            "description": "Zona de Distribición 1 de Región Metropolitan",
            "cross_docking_locations": ["Bodega01-SCL-Test"]
        }

        result = distribution_zone_client.create(distribution_zone)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        geographic_coverage_client = GeographicCoverageClient(**API_ACCESS_CONFIG)
        geographic_coverage = {
            "address_structure_id": 13132,
            "distribution_zone_code": distribution_zone['code']
        }

        result = geographic_coverage_client.create(geographic_coverage)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        regional_partner_client = RegionalPartnerClient(**API_ACCESS_CONFIG)
        regional_partner = {
            'code': '88888888-8',
            'name': 'Last Mile Cargo',
            'location': {
                'country_code': 'CL',
                'zone_type': 1,
                'geo_coding': 'Avenida Vitacura 4380, Vitacura, Chile',
                'geo_location': {
                    'lat': -33.398823,
                    'lon': -70.588274
                },
                'what3words': 'liner.cooking.montage',
                'reference': 'En la esquina de Vitacura con Américo Vespucio',
                'structure_id': 13132,
                'street': 'Vitacura',
                'number': '4380',
                'sector': '',
            },
            'distribution_zone_codes': [distribution_zone['code']],
            'internal_code': '1'
        }

        result = regional_partner_client.create(regional_partner)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        service_level_client = ServiceLevelClient(**API_ACCESS_CONFIG)
        service_level = {
            "product_template_code": product_template['code'],
            "distribution_zone_code": distribution_zone['code'],
            "b2b_delivery": {
                "time_interval": 1,
                "failure_rate": 10
            },
            "b2b_reception": {
                "time_interval": 1,
                "failure_rate": 10
            },
            "fixed_packaging": {
                "time_interval": 1,
                "failure_rate": 10
            },
            "mobile_packaging": {
                "time_interval": 1,
                "failure_rate": 10
            },
            "carrier_dispatch": {
                "time_interval": 1,
                "failure_rate": 10
            },
            "carrier_delivery": {
                "time_interval": 1,
                "failure_rate": 10
            },
            "ser_reception": {
                "time_interval": 1,
                "failure_rate": 10
            },
            "vehicle_load": {
                "time_interval": 1,
                "failure_rate": 10
            },
            "b2c_delivery": {
                "time_interval": 1,
                "failure_rate": 10
            },
        }

        result = service_level_client.create(service_level)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)
        service_level_id = result.content['service_level_id']

        # DeliveryOrderRequest Tests

        delivery_order_request_client = DeliveryOrderRequestClient(**API_ACCESS_CONFIG)
        delivery_order_request = {
            "sender_code": "33333333-3",
            "receiver": {
                "code": "10101010-1",
                "first_name": "Joh",
                "last_name": "Doe",
                "mobile_phone": "912345678",
                "email": "john.doe@gmail.com"
            },
            "products": [
                {
                    "code": "1234567abcd",
                    "product_template_code": "KitPrepagoDTV-Test",
                }
            ],
            "destination": {
                "country_code": "CL",
                "structure_id": 13132,
                "street": "Vitacura",
                "number": "4380",
                "local": "piso 15",
                "geo_coding": "Avenida Vitacura 4380, Vitacura",
                "geo_location": {
                    "lat": -33.398823,
                    "lon": -70.588274
                },
                "what3words": "liner.cooking.montage"
            },
            "priority": 1,
            "status": 1
        }

        result = delivery_order_request_client.create(delivery_order_request)
        self.assertTrue(result.response.status == 200 and result.content)
        delivery_order_request_id = result.content['delivery_order_request_id']
        time.sleep(0.5)

        result = delivery_order_request_client.get_by_id(delivery_order_request_id)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = delivery_order_request_client.get_by_id('123456')
        self.assertTrue(result.response.status == 404)
        time.sleep(0.5)

        result = delivery_order_request_client.search({'product_code': '1234567abcd'})
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = delivery_order_request_client.delete(delivery_order_request_id)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = delivery_order_request_client.create(delivery_order_request)
        self.assertTrue(result.response.status == 200 and result.content)
        delivery_order_request_id = result.content['delivery_order_request_id']
        time.sleep(0.5)

        delivery_order_request['receiver']['first_name'] += 'n'
        result = delivery_order_request_client.update(delivery_order_request, delivery_order_request_id)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = delivery_order_request_client.delete(delivery_order_request_id)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        # Tests Cleanup

        result = b2b_client.delete('33333333-3')
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = regional_partner_client.delete('88888888-8')
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = employee_client.delete('22222222-2')
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = b2c_client.delete("10101010-1")
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = packaging_location_client.delete(packaging_location['code'])
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = service_level_client.delete(service_level_id)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = distribution_zone_client.delete("RM-01-Test")
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = cross_docking_location_client.delete("Bodega01-SCL-Test")
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = geographic_coverage_client.delete(13132)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = package_template_client.delete('Box1-Test')
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = product_template_client.delete('KitPrepagoDTV-Test')
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = contact_client.delete('44444444-4')
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)


if __name__ == '__main__':
    unittest.main()



import base64
import contextlib
import httplib
import os
import ssl
import urlparse
import json
import requests
from requests.auth import HTTPBasicAuth

from httplib2 import socks, AllHosts, ProxyInfo

import sys
reload(sys)
sys.setdefaultencoding('utf8')

URL_FETCH_DEADLINE = 300


def proxy_info_from_environment(method='http'):
    if method not in ['http', 'https']:
        return

    env_var = method + '_proxy'
    url = os.environ.get(env_var, os.environ.get(env_var.upper()))

    if not url:
        return

    pi = proxy_info_from_url(url, method)

    no_proxy = os.environ.get('no_proxy', os.environ.get('NO_PROXY', ''))
    bypass_hosts = []
    if no_proxy:
        bypass_hosts = no_proxy.split(',')
    # special case, no_proxy=* means all hosts bypassed
    if no_proxy == '*':
        bypass_hosts = AllHosts

    pi.bypass_hosts = bypass_hosts
    return pi


def proxy_info_from_url(url, method='http'):
    url = urlparse.urlparse(url)
    username = None
    password = None
    port = None
    if '@' in url[1]:
        ident, host_port = url[1].split('@', 1)
        if ':' in ident:
            username, password = ident.split(':', 1)
        else:
            password = ident
    else:
        host_port = url[1]
    if ':' in host_port:
        host, port = host_port.split(':', 1)
    else:
        host = host_port

    if port:
        port = int(port)
    else:
        port = dict(https=443, http=80)[method]

    proxy_type = socks.PROXY_TYPE_HTTP_NO_TUNNEL
    return ProxyInfo(
        proxy_type=proxy_type,
        proxy_host=host,
        proxy_port=port,
        proxy_user=username or None,
        proxy_pass=password or None
    )


class ApiClientBase(object):
    def __init__(self, **kwargs):
        self.for_app_engine = kwargs['for_app_engine'] if 'for_app_engine' in kwargs else True
        self.base_url = ''
        self.headers = {}

        if not kwargs:
            raise Exception('Must specify arguments.')

        self.base_url = kwargs['base_url']
        self.headers = {
            'Accept': 'application/json',
            'Content-Type': 'application/json; charset=UTF-8'
        }

        _url_parsed = urlparse.urlparse(self.base_url)
        self.host = _url_parsed.hostname
        self.port = _url_parsed.port
        self.scheme = _url_parsed.scheme

        self.username = kwargs['user_name']
        self.password = kwargs['password']
        if self.username and self.password:
            self.headers['Authorization'] = \
                'Basic ' + base64.encodestring(self.username + ':' + self.password).replace(os.linesep, '')
            self.requests_auth = HTTPBasicAuth(self.username, self.password)
        else:
            self.requests_auth = None

        self.args = kwargs
        self.timeout = 60
        self.source_address = kwargs['source_address'] if 'source_address' in kwargs else None

        if self.for_app_engine:
            import requests_toolbelt.adapters.appengine
            requests_toolbelt.adapters.appengine.monkeypatch()

    @contextlib.contextmanager
    def _get_client(self):
        pi = proxy_info_from_environment()
        if pi:
            if self.scheme == 'http':
                yield httplib.HTTPConnection(
                    pi.proxy_host,
                    pi.proxy_port,
                    timeout=self.timeout,
                    source_address=self.source_address
                )
            else:
                yield httplib.HTTPSConnection(
                    pi.proxy_host,
                    pi.proxy_port,
                    timeout=self.timeout,
                    context=ssl._create_unverified_context(),
                    source_address=self.source_address
                )
        else:
            self.base_url = ''
            if self.scheme == 'http':
                yield httplib.HTTPConnection(
                    self.host,
                    self.port,
                    source_address=self.source_address
                )
            else:
                yield httplib.HTTPSConnection(
                    self.host,
                    self.port,
                    context=ssl._create_unverified_context(),
                    source_address=self.source_address
                )

    def _process_response(self, response, content, json_response=True):
        if self.for_app_engine:
            response.status = response.status_code

        if not json_response:
            return ApiClientResponse(response=response, content=content)
        else:
            content_json = None
            try:
                content_json = json.loads(content)
            except Exception as e:
                pass

            return ApiClientResponse(response=response, content=content_json)

    def http_get_json(self, url):
        if self.for_app_engine:
            from google.appengine.api import urlfetch
            urlfetch.set_default_fetch_deadline(URL_FETCH_DEADLINE)

            response = requests.get(self.base_url + url, auth=self.requests_auth)
            return self._process_response(response, response.content)
        else:
            with self._get_client() as _client:
                _client.request(method="GET", url=self.base_url + url, headers=self.headers)
                _response = _client.getresponse()
                return self._process_response(_response, _response.read())

    def http_get(self, url):
        if self.for_app_engine:
            from google.appengine.api import urlfetch
            urlfetch.set_default_fetch_deadline(URL_FETCH_DEADLINE)

            response = requests.get(self.base_url + url, auth=self.requests_auth)
            return self._process_response(response, response.content, False)
        else:
            with self._get_client() as _client:
                _client.request(method="GET", url=self.base_url + url, headers=self.headers)
                _response = _client.getresponse()
                return self._process_response(_response, _response.read(), False)

    def http_put_json(self, url, obj):
        if self.for_app_engine:
            from google.appengine.api import urlfetch
            urlfetch.set_default_fetch_deadline(URL_FETCH_DEADLINE)

            response = requests.put(self.base_url + url, auth=self.requests_auth, json=obj)
            return self._process_response(response, response.content)
        else:
            with self._get_client() as _client:
                _client.request(method="PUT", url=self.base_url + url, body=json.dumps(obj), headers=self.headers)
                _response = _client.getresponse()
                return self._process_response(_response, _response.read())

    def http_post_json(self, url, obj):
        if self.for_app_engine:
            from google.appengine.api import urlfetch
            urlfetch.set_default_fetch_deadline(URL_FETCH_DEADLINE)

            response = requests.post(self.base_url + url, auth=self.requests_auth, json=obj)
            return self._process_response(response, response.content)
        else:
            with self._get_client() as _client:
                _client.request(method="POST", url=self.base_url + url, body=json.dumps(obj), headers=self.headers)
                _response = _client.getresponse()
                return self._process_response(_response, _response.read())

    def http_post(self, url, data):
        if self.for_app_engine:
            from google.appengine.api import urlfetch
            urlfetch.set_default_fetch_deadline(URL_FETCH_DEADLINE)

            response = requests.post(self.base_url + url, auth=self.requests_auth, data=data)
            return self._process_response(response, response.content, json_response=False)
        else:
            with self._get_client() as _client:
                _client.request(method="POST", url=self.base_url + url, body=data, headers=self.headers)
                _response = _client.getresponse()
                return self._process_response(_response, _response.read(), json_response=False)

    def http_delete(self, url, data=None):
        if self.for_app_engine:
            from google.appengine.api import urlfetch
            urlfetch.set_default_fetch_deadline(URL_FETCH_DEADLINE)

            response = requests.delete(self.base_url + url, auth=self.requests_auth, data=data)
            return self._process_response(response, response.content)
        else:
            with self._get_client() as _client:
                _client.request(method="DELETE", url=self.base_url + url, body=data, headers=self.headers)
                _response = _client.getresponse()
                return self._process_response(_response, _response.read(), json_response=False)


class ApiClientResponse(object):
    def __init__(self, response, content):
        self.response = response
        self.content = content


class EntityClientBase(ApiClientBase):
    entity_endpoint_base_url = ''

    def __init__(self, **kwargs):
        super(EntityClientBase, self).__init__(**kwargs)

    def _validate(self):
        if self.entity_endpoint_base_url == '':
            raise Exception("Must set entity_api_base_url field.")

    def get_list(self):
        self._validate()
        return self.http_get_json(self.entity_endpoint_base_url)

    def get_by_id(self, id):
        self._validate()
        return self.http_get_json(self.entity_endpoint_base_url + str(id))

    def search(self, search_info):
        self._validate()
        return self.http_post_json(self.entity_endpoint_base_url + "_search", search_info)

    def create(self, entity):
        self._validate()
        return self.http_post_json(self.entity_endpoint_base_url, entity)

    def bulk_create(self, entity):
        self._validate()
        return self.http_post_json(self.entity_endpoint_base_url + '_bulk-create', entity)

    def update(self, entity, id):
        self._validate()
        return self.http_put_json(self.entity_endpoint_base_url + str(id), entity)

    def delete(self, id):
        self._validate()
        return self.http_delete(self.entity_endpoint_base_url + str(id))

    def bulk_delete(self, entities_id):
        self._validate()
        return self.http_post_json(self.entity_endpoint_base_url + '_bulk-delete', entities_id)


if __name__ == '__main__':
    API_ACCESS_CONFIG = {
        'base_url': "http://localhost:8081",
        'user_name': 'webapi',
        'password': '2wsxzaq1'
    }

    API_ACCESS_CONFIG.update({'for_app_engine': False})

    client = EntityClientBase(**API_ACCESS_CONFIG)
    client.entity_endpoint_base_url = '/management/roles/'
    result = client.get_list()
    print result.response.status, result.content

    entity = result.content[0]
    result = client.update(entity, entity['name'])
    print result.response.status, result.content




import unittest

import time

from alas_ce0.management.employee import EmployeeClient

from config import API_ACCESS_CONFIG


class TestEmployeeApi(unittest.TestCase):
    def test_crud(self):
        # Employee Tests

        employee_client = EmployeeClient(**API_ACCESS_CONFIG)
        employee = {
            'code': '22222222-2',
            'first_name': 'First Nam',
            'last_name': 'Last Name',
            'birth_date': '1991-01-01',
            'gender': 1,
            'internal_code': '1',
            'status': 1
        }

        result = employee_client.create(employee)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = employee_client.get_by_id(result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)

        result = employee_client.get_by_id('55555555-5')
        self.assertTrue(result.response.status == 404)

        result = employee_client.search({'birth_date': '1991-01-01', 'last_name': 'Last Name'})
        self.assertTrue(result.response.status == 200 and result.content)

        result = employee_client.delete(result.content['items'][0]['code'])
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = employee_client.create(employee)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        employee['first_name'] += 'e'
        result = employee_client.update(employee, result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = employee_client.delete("22222222-2")
        self.assertTrue(result.response.status == 204)
        time.sleep(1)


if __name__ == '__main__':
    unittest.main()



# coding=utf-8
import time
import unittest

from alas_ce0.management.contact import ContactClient

from config import API_ACCESS_CONFIG


class TestContactApi(unittest.TestCase):
    def test_crud(self):
        # Contact Tests

        contact_client = ContactClient(**API_ACCESS_CONFIG)
        contact = {
            'code': '44444444-4',
            'first_name': 'Contact FirstName',
            'last_name': 'Contact LastName',
            'land_line': '221345678',
            'mobile_phone': '921345678',
            'email': 'contact@gmail.com',
            'web': 'http://www.contact.com'
        }

        result = contact_client.create(contact)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = contact_client.get_by_id(result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)

        result = contact_client.search({'code': contact['code']})
        self.assertTrue(result.response.status == 200 and result.content)

        result = contact_client.get_by_id('sample-contact')
        self.assertTrue(result.response.status == 404)

        result = contact_client.delete(contact['code'])
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = contact_client.create(contact)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        contact['web'] += '/test'

        result = contact_client.update(contact, contact['code'])
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = contact_client.delete('44444444-4')
        self.assertTrue(result.response.status == 204)
        time.sleep(1)


if __name__ == '__main__':
    unittest.main()



# coding=utf-8
import unittest

import time
from alas_ce0.management.feature import FeatureClient
from alas_ce0.management.resource import ResourceClient

from config import API_ACCESS_CONFIG


class TestFeatureApi(unittest.TestCase):
    def test_crud(self):
        # Tests Setup

        resource_client = ResourceClient(**API_ACCESS_CONFIG)
        resource = {
            'description': 'TestResource',
            'target': '/target'
        }

        result = resource_client.create(resource)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)
        resource_id = result.content['resource_id']

        # Feature Tests

        feature_client = FeatureClient(**API_ACCESS_CONFIG)
        feature = {
            'name': 'TestFeature',
            'description': 'TestFeatur',
            'resources': [resource_id]
        }

        result = feature_client.create(feature)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = feature_client.get_by_id(result.content['name'])
        self.assertTrue(result.response.status == 200 and result.content)

        result = feature_client.get_by_id('sample-feature')
        self.assertTrue(result.response.status == 404)

        result = feature_client.search({'description': 'TestFeatur'})
        self.assertTrue(result.response.status == 200 and result.content)

        result = feature_client.delete(result.content['items'][0]['name'])
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = feature_client.create(feature)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        feature['description'] += 'e'
        result = feature_client.update(feature, result.content['name'])
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = feature_client.delete('TestFeature')
        self.assertTrue(result.response.status == 204)
        time.sleep(1)

        # Tests Cleanup

        result = resource_client.delete(resource_id)
        self.assertTrue(result.response.status == 204)
        time.sleep(1)


if __name__ == '__main__':
    unittest.main()



# coding=utf-8
import time
import unittest

from alas_ce0.management.vehicle import CargoVehicleTemplateClient

from config import API_ACCESS_CONFIG


class TestCargoVehicleApi(unittest.TestCase):
    def test_crud(self):
        # CargoVehicle Tests

        cargo_vehicle_template_client = CargoVehicleTemplateClient(**API_ACCESS_CONFIG)
        cargo_vehicle_template = {
            "brand": "BRAND",
            "model": "MODEL",
            "cargo_weight": 4350,
            "cargo_volume": 13.0,
            "delivery_cargo_volume": {
                "width": 50.25,
                "height": 60.13,
                "depth": 25.34
            }
        }

        result = cargo_vehicle_template_client.create(cargo_vehicle_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = cargo_vehicle_template_client.get_by_id(result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)

        result = cargo_vehicle_template_client.search({'code': result.content['code']})
        self.assertTrue(result.response.status == 200 and result.content)

        cargo_vehicle_template_code = result.content['items'][0]['code']
        result = cargo_vehicle_template_client.get_by_id('sample-cargo-vehicle')
        self.assertTrue(result.response.status == 404)

        result = cargo_vehicle_template_client.delete(cargo_vehicle_template_code)
        self.assertTrue(result.response.status == 204)
        time.sleep(0.5)

        result = cargo_vehicle_template_client.create(cargo_vehicle_template)
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        cargo_vehicle_template['cargo_volume'] = 13.1
        result = cargo_vehicle_template_client.update(cargo_vehicle_template, result.content['code'])
        self.assertTrue(result.response.status == 200 and result.content)
        time.sleep(0.5)

        result = cargo_vehicle_template_client.delete(result.content['code'])
        self.assertTrue(result.response.status == 204)
        time.sleep(1)


if __name__ == '__main__':
    unittest.main()



from alas_ce0.common.client_base import EntityClientBase


class ReportClient(EntityClientBase):
    entity_endpoint_base_url = '/reporting/reports/'

    def get_content(self, id):
        return self.http_get(
            self.entity_endpoint_base_url + "{0}/_content".format(id)
        )


from alas_ce0.common.client_base import EntityClientBase


class EmployeeClient(EntityClientBase):
    entity_endpoint_base_url = '/management/employees/'

    def __init__(self, country_code='cl', **kwargs):
        super(EmployeeClient, self).__init__(**kwargs)
        self.entity_endpoint_base_url += country_code + '/'

    def is_work_day(self, work_day=None):
        return self.http_post_json(
            self.entity_endpoint_base_url + "_is-work-day",
            {'work_day': work_day} if work_day else {}
        )



# coding=utf-8
import time
import unittest

from alas_ce0.delivery.b2c import B2CClient

from config import API_ACCESS_CONFIG


class TestB2CApi(unittest.TestCase):
    def test_crud(self):
        # B2C Tests

        b2c_client = B2CClient(**API_ACCESS_CONFIG)
        b2c = {
            "code": "10101010-1",
            "first_name": "Joh",
            "last_name": "Doe",
            "mobile_phone": "912345678",
            "email": "john.doe@gmail.com"
        }

        result = b2c_client.create(b2c)
        self.assertTrue(result.response.status == 200 and result.content)

        result = b2c_client.get_by_id("10101010-1")
        self.assertTrue(result.response.status == 200 and result.content)

        result = b2c_client.get_by_id('123456')
        self.assertTrue(result.response.status == 404)

        result = b2c_client.search({'first_name': 'Joh'})
        self.assertTrue(result.response.status == 200 and result.content)

        result = b2c_client.delete("10101010-1")
        self.assertTrue(result.response.status == 204)

        result = b2c_client.create(b2c)
        self.assertTrue(result.response.status == 200 and result.content)

        b2c['first_name'] += 'n'
        result = b2c_client.update(b2c, "10101010-1")
        self.assertTrue(result.response.status == 200 and result.content)

        result = b2c_client.delete("10101010-1")
        self.assertTrue(result.response.status == 204)


if __name__ == '__main__':
    unittest.main()
